#!/bin/bash
# Conversor de fichero de texto UTF-8 en español
# a la codificación de caracteres del Sinclair QL

# Verifica que se haya proporcionado al menos un argumento
if [ "$#" -lt 1 ]; then
    echo "Uso: $0 <archivo_entrada>"
    exit 1
fi

# Si es necesario, establece el locale a uno compatible con UTF-8
# export LANG='es_ES.UTF-8'

# Tabla de conversión
declare -A replacements=(
    [á]="" [é]="" [í]="" [ó]="" [ú]="" [ü]=""
    [Á]="A" [É]="£" [Í]="I" [Ó]="O" [Ú]="U" [Ü]="§"
    [ç]="" [Ç]="š" [ñ]="" [Ñ]="©" [¿]="Ž" [¡]="³"
)

# Define el archivo de entrada
input_file="$1"

echo "Procesando: $input_file..."

# Extrae el nombre base del archivo sin la extensión
base_name=$(basename -- "$input_file")
extension="${base_name##*.}"
name_without_extension="${base_name%.*}"

# Crea el nombre del archivo de salida
output_file="${name_without_extension}_converted.${extension}"

# Copia el contenido del archivo de entrada al archivo de salida
cp "$input_file" "$output_file"

# Realiza las sustituciones en el archivo de salida
for key in "${!replacements[@]}"; do
    value=${replacements[$key]}
    # Usa sed para realizar las sustituciones en el archivo de salida
    sed -i "s/$key/$value/g" "$output_file"
done

# Convierte el archivo de salida a ISO-8859-15
iconv -f UTF-8 -t ISO-8859-15 "$output_file" -o "$output_file"

echo " Resultado: ${output_file}"

